# Lirian Su's Configuration, 我的配置

[![Build Status][badge-travis]][travis] [![PyPI][badge-pypi]][pypi]

[我][me]的[开发环境是 Windows 系统][win-env]，
时常也会在 Unix 系统上游荡。
因为经常折腾环境，
所以本项目就是用来同步我常用的配置的。


## 风格介绍

我的风格是懒人专用，而且任何改动都是附加项，不会变动原有的任何命令习惯。


## 快速安装

首先，确保环境中有 Python 3.5+，然后使用 `pip` 快速安装：

```
pip install lki && lki install
```

> 本命令同时支持 Unix, MacOS, Windows 环境


## 开源协议

[宽松的 MIT License][license],
意味着你可以做任何更改，
甚至把作者名都改成你。


## 我有问题要问

没关系，不论是对项目的问题还是对我个人的问题，
或者是你觉得哪条命令不够好用，
都欢迎[来项目里直接提 Issue。][issue]


[badge-pypi]: https://img.shields.io/pypi/v/lki.svg
[badge-travis]: https://travis-ci.org/LKI/LKI.svg?branch=master
[issue]: https://github.com/LKI/LKI/issues/new
[license]: https://github.com/LKI/LKI/blob/master/LICENSE
[me]: https://www.liriansu.com/about
[pypi]: [![PyPI](https://img.shields.io/pypi/v/lki.svg)](https://pypi.python.org/pypi/lki)
[travis]: https://travis-ci.org/LKI/LKI
[win-env]: https://www.liriansu.com/windows-dev-env
